@@ -68,8 +68,9 @@ from .registry import models_registry, register_model
 from .base import DEFERRED, Model  # isort:skip
 from .fields.related import (  # isort:skip
     ForeignKey,
-    ForeignObject,
     ManyToManyField,
+)
+from .fields.reverse_related import (  # isort:skip
     ForeignObjectRel,
     ManyToOneRel,
     ManyToManyRel,
@@ -116,7 +117,6 @@ __all__ += [
     "Model",
     "FilteredRelation",
     "ForeignKey",
-    "ForeignObject",
     "ManyToManyField",
     "ForeignObjectRel",
     "ManyToOneRel",
