@@ -8,24 +8,20 @@ import warnings
 import zoneinfo
 from collections import deque
 from contextlib import contextmanager
+from functools import cached_property
 
-from plain.exceptions import ImproperlyConfigured
 from plain.models.backends import utils
 from plain.models.backends.base.validation import BaseDatabaseValidation
-from plain.models.backends.signals import connection_created
 from plain.models.backends.utils import debug_transaction
 from plain.models.db import (
-    DEFAULT_DB_ALIAS,
     DatabaseError,
     DatabaseErrorWrapper,
     NotSupportedError,
 )
 from plain.models.transaction import TransactionManagementError
 from plain.runtime import settings
-from plain.utils.functional import cached_property
 
-NO_DB_ALIAS = "__no_db__"
-RAN_DB_VERSION_CHECK = set()
+RAN_DB_VERSION_CHECK = False
 
 logger = logging.getLogger("plain.models.backends.base")
 
@@ -53,7 +49,7 @@ class BaseDatabaseWrapper:
 
     queries_limit = 9000
 
-    def __init__(self, settings_dict, alias=DEFAULT_DB_ALIAS):
+    def __init__(self, settings_dict):
         # Connection related attributes.
         # The underlying database connection.
         self.connection = None
@@ -61,7 +57,6 @@ class BaseDatabaseWrapper:
         # NAME, USER, etc. It's called `settings_dict` instead of `settings`
         # to disambiguate it from Plain settings modules.
         self.settings_dict = settings_dict
-        self.alias = alias
         # Query logging in debug mode or when explicitly enabled.
         self.queries_log = deque(maxlen=self.queries_limit)
         self.force_debug_cursor = False
@@ -122,10 +117,7 @@ class BaseDatabaseWrapper:
         self.validation = self.validation_class(self)
 
     def __repr__(self):
-        return (
-            f"<{self.__class__.__qualname__} "
-            f"vendor={self.vendor!r} alias={self.alias!r}>"
-        )
+        return f"<{self.__class__.__qualname__} vendor={self.vendor!r}>"
 
     def ensure_timezone(self):
         """
@@ -150,10 +142,8 @@ class BaseDatabaseWrapper:
         Plain uses may be constrained by the requirements of other users of
         the database.
         """
-        if not settings.USE_TZ:
-            return None
-        elif self.settings_dict["TIME_ZONE"] is None:
-            return datetime.timezone.utc
+        if self.settings_dict["TIME_ZONE"] is None:
+            return datetime.UTC
         else:
             return zoneinfo.ZoneInfo(self.settings_dict["TIME_ZONE"])
 
@@ -162,9 +152,7 @@ class BaseDatabaseWrapper:
         """
         Name of the time zone of the database connection.
         """
-        if not settings.USE_TZ:
-            return settings.TIME_ZONE
-        elif self.settings_dict["TIME_ZONE"] is None:
+        if self.settings_dict["TIME_ZONE"] is None:
             return "UTC"
         else:
             return self.settings_dict["TIME_ZONE"]
@@ -177,8 +165,8 @@ class BaseDatabaseWrapper:
     def queries(self):
         if len(self.queries_log) == self.queries_log.maxlen:
             warnings.warn(
-                "Limit for query logging exceeded, only the last {} queries "
-                "will be returned.".format(self.queries_log.maxlen)
+                f"Limit for query logging exceeded, only the last {self.queries_log.maxlen} queries "
+                "will be returned."
             )
         return list(self.queries_log)
 
@@ -224,9 +212,9 @@ class BaseDatabaseWrapper:
     def init_connection_state(self):
         """Initialize the database connection settings."""
         global RAN_DB_VERSION_CHECK
-        if self.alias not in RAN_DB_VERSION_CHECK:
+        if not RAN_DB_VERSION_CHECK:
             self.check_database_version_supported()
-            RAN_DB_VERSION_CHECK.add(self.alias)
+            RAN_DB_VERSION_CHECK = True
 
     def create_cursor(self, name=None):
         """Create a cursor. Assume that a connection is established."""
@@ -238,8 +226,6 @@ class BaseDatabaseWrapper:
 
     def connect(self):
         """Connect to the database. Assume that the connection is closed."""
-        # Check for invalid configurations.
-        self.check_settings()
         # In case the previous connection was closed while in an atomic block
         self.in_atomic_block = False
         self.savepoint_ids = []
@@ -258,17 +244,9 @@ class BaseDatabaseWrapper:
         self.connection = self.get_new_connection(conn_params)
         self.set_autocommit(self.settings_dict["AUTOCOMMIT"])
         self.init_connection_state()
-        connection_created.send(sender=self.__class__, connection=self)
 
         self.run_on_commit = []
 
-    def check_settings(self):
-        if self.settings_dict["TIME_ZONE"] is not None and not settings.USE_TZ:
-            raise ImproperlyConfigured(
-                "Connection '%s' cannot set TIME_ZONE because USE_TZ is False."
-                % self.alias
-            )
-
     def ensure_connection(self):
         """Guarantee that a connection to the database is established."""
         if self.connection is None:
@@ -386,7 +364,7 @@ class BaseDatabaseWrapper:
         tid = str(thread_ident).replace("-", "")
 
         self.savepoint_state += 1
-        sid = "s%s_x%d" % (tid, self.savepoint_state)
+        sid = "s%s_x%d" % (tid, self.savepoint_state)  # noqa: UP031
 
         self.validate_thread_sharing()
         self._savepoint(sid)
@@ -514,18 +492,6 @@ class BaseDatabaseWrapper:
 
     # ##### Foreign key constraints checks handling #####
 
-    @contextmanager
-    def constraint_checks_disabled(self):
-        """
-        Disable foreign key constraint checking.
-        """
-        disabled = self.disable_constraint_checking()
-        try:
-            yield
-        finally:
-            if disabled:
-                self.enable_constraint_checking()
-
     def disable_constraint_checking(self):
         """
         Backends can implement as needed to temporarily disable foreign key
@@ -611,18 +577,6 @@ class BaseDatabaseWrapper:
         with self._thread_sharing_lock:
             return self._thread_sharing_count > 0
 
-    def inc_thread_sharing(self):
-        with self._thread_sharing_lock:
-            self._thread_sharing_count += 1
-
-    def dec_thread_sharing(self):
-        with self._thread_sharing_lock:
-            if self._thread_sharing_count <= 0:
-                raise RuntimeError(
-                    "Cannot decrement the thread sharing count below zero."
-                )
-            self._thread_sharing_count -= 1
-
     def validate_thread_sharing(self):
         """
         Validate that the connection isn't accessed by another thread than the
@@ -633,11 +587,9 @@ class BaseDatabaseWrapper:
         if not (self.allow_thread_sharing or self._thread_ident == _thread.get_ident()):
             raise DatabaseError(
                 "DatabaseWrapper objects created in a "
-                "thread can only be used in that same thread. The object "
-                "with alias '{}' was created in thread id {} and this is "
-                "thread id {}.".format(
-                    self.alias, self._thread_ident, _thread.get_ident()
-                )
+                "thread can only be used in that same thread. The connection "
+                f"was created in thread id {self._thread_ident} and this is "
+                f"thread id {_thread.get_ident()}."
             )
 
     # ##### Miscellaneous #####
@@ -698,7 +650,7 @@ class BaseDatabaseWrapper:
         being exposed to potential child threads while (or after) the test
         database is destroyed. Refs #10868, #17786, #16969.
         """
-        conn = self.__class__({**self.settings_dict, "NAME": None}, alias=NO_DB_ALIAS)
+        conn = self.__class__({**self.settings_dict, "NAME": None})
         try:
             with conn.cursor() as cursor:
                 yield cursor
@@ -771,13 +723,11 @@ class BaseDatabaseWrapper:
         finally:
             self.execute_wrappers.pop()
 
-    def copy(self, alias=None):
+    def copy(self):
         """
         Return a copy of this connection.
 
         For tests that require two connections to the same database.
         """
         settings_dict = copy.deepcopy(self.settings_dict)
-        if alias is None:
-            alias = self.alias
-        return type(self)(settings_dict, alias)
+        return type(self)(settings_dict)
