@@ -2,7 +2,6 @@ import os
 import subprocess
 import sys
 import time
-from itertools import takewhile
 
 import click
 
@@ -22,12 +21,10 @@ from .migrations.migration import Migration, SettingsTuple
 from .migrations.optimizer import MigrationOptimizer
 from .migrations.questioner import (
     InteractiveMigrationQuestioner,
-    MigrationQuestioner,
     NonInteractiveMigrationQuestioner,
 )
 from .migrations.recorder import MigrationRecorder
 from .migrations.state import ModelState, ProjectState
-from .migrations.utils import get_migration_name_timestamp
 from .migrations.writer import MigrationWriter
 from .registry import models_registry
 
@@ -92,10 +89,41 @@ def db_wait():
                 )
             time.sleep(1.5)
         else:
-            click.secho("Database ready", fg="green")
+            click.secho("✔ Database ready", fg="green")
             break
 
 
+@cli.command(name="list")
+@click.argument("package_labels", nargs=-1)
+@click.option(
+    "--app-only",
+    is_flag=True,
+    help="Only show models from packages that start with 'app'.",
+)
+def list_models(package_labels, app_only):
+    """List installed models."""
+
+    packages = set(package_labels)
+
+    for model in sorted(
+        models_registry.get_models(),
+        key=lambda m: (m._meta.package_label, m._meta.model_name),
+    ):
+        pkg = model._meta.package_label
+        pkg_name = packages_registry.get_package_config(pkg).name
+        if app_only and not pkg_name.startswith("app"):
+            continue
+        if packages and pkg not in packages:
+            continue
+        fields = ", ".join(f.name for f in model._meta.get_fields())
+        click.echo(
+            f"{click.style(pkg, fg='cyan')}.{click.style(model.__name__, fg='blue')}"
+        )
+        click.echo(f"  table: {model._meta.db_table}")
+        click.echo(f"  fields: {fields}")
+        click.echo(f"  package: {pkg_name}\n")
+
+
 @register_cli("makemigrations")
 @cli.command()
 @click.argument("package_labels", nargs=-1)
@@ -104,7 +132,6 @@ def db_wait():
     is_flag=True,
     help="Just show what migrations would be made; don't actually write them.",
 )
-@click.option("--merge", is_flag=True, help="Enable fixing of migration conflicts.")
 @click.option("--empty", is_flag=True, help="Create an empty migration.")
 @click.option(
     "--noinput",
@@ -126,9 +153,7 @@ def db_wait():
     default=1,
     help="Verbosity level; 0=minimal output, 1=normal output, 2=verbose output, 3=very verbose output",
 )
-def makemigrations(
-    package_labels, dry_run, merge, empty, no_input, name, check, verbosity
-):
+def makemigrations(package_labels, dry_run, empty, no_input, name, check, verbosity):
     """Creates new migration(s) for packages."""
 
     written_files = []
@@ -195,103 +220,6 @@ def makemigrations(
                     )
                     log(writer.as_string(), level=3)
 
-    def handle_merge(loader, conflicts):
-        """Handle merging conflicting migrations."""
-        if interactive:
-            questioner = InteractiveMigrationQuestioner()
-        else:
-            questioner = MigrationQuestioner(defaults={"ask_merge": True})
-
-        for package_label, migration_names in conflicts.items():
-            log(click.style(f"Merging {package_label}", fg="cyan", bold=True), level=1)
-
-            merge_migrations = []
-            for migration_name in migration_names:
-                migration = loader.get_migration(package_label, migration_name)
-                migration.ancestry = [
-                    mig
-                    for mig in loader.graph.forwards_plan(
-                        (package_label, migration_name)
-                    )
-                    if mig[0] == migration.package_label
-                ]
-                merge_migrations.append(migration)
-
-            def all_items_equal(seq):
-                return all(item == seq[0] for item in seq[1:])
-
-            merge_migrations_generations = zip(*(m.ancestry for m in merge_migrations))
-            common_ancestor_count = sum(
-                1 for _ in takewhile(all_items_equal, merge_migrations_generations)
-            )
-            if not common_ancestor_count:
-                raise ValueError(f"Could not find common ancestor of {migration_names}")
-
-            for migration in merge_migrations:
-                migration.branch = migration.ancestry[common_ancestor_count:]
-                migrations_ops = (
-                    loader.get_migration(node_package, node_name).operations
-                    for node_package, node_name in migration.branch
-                )
-                migration.merged_operations = sum(migrations_ops, [])
-
-            for migration in merge_migrations:
-                log(click.style(f"  Branch {migration.name}", fg="yellow"), level=1)
-                for operation in migration.merged_operations:
-                    log(f"    - {operation.describe()}", level=1)
-
-            if questioner.ask_merge(package_label):
-                numbers = [
-                    MigrationAutodetector.parse_number(migration.name)
-                    for migration in merge_migrations
-                ]
-                biggest_number = (
-                    max(x for x in numbers if x is not None) if numbers else 0
-                )
-
-                subclass = type(
-                    "Migration",
-                    (Migration,),
-                    {
-                        "dependencies": [
-                            (package_label, migration.name)
-                            for migration in merge_migrations
-                        ],
-                    },
-                )
-
-                parts = [f"{biggest_number + 1:04d}"]
-                if migration_name:
-                    parts.append(migration_name)
-                else:
-                    parts.append("merge")
-                    leaf_names = "_".join(
-                        sorted(migration.name for migration in merge_migrations)
-                    )
-                    if len(leaf_names) > 47:
-                        parts.append(get_migration_name_timestamp())
-                    else:
-                        parts.append(leaf_names)
-
-                new_migration_name = "_".join(parts)
-                new_migration = subclass(new_migration_name, package_label)
-                writer = MigrationWriter(new_migration)
-
-                if not dry_run:
-                    with open(writer.path, "w", encoding="utf-8") as fh:
-                        fh.write(writer.as_string())
-                    log(f"\nCreated new merge migration {writer.path}", level=1)
-                elif verbosity == 3:
-                    log(
-                        click.style(
-                            f"Full merge migrations file '{writer.filename}':",
-                            fg="cyan",
-                            bold=True,
-                        ),
-                        level=3,
-                    )
-                    log(writer.as_string(), level=3)
-
     # Validate package labels
     package_labels = set(package_labels)
     has_bad_labels = False
@@ -320,21 +248,16 @@ def makemigrations(
             if package_label in package_labels
         }
 
-    if conflicts and not merge:
+    if conflicts:
         name_str = "; ".join(
             "{} in {}".format(", ".join(names), package)
             for package, names in conflicts.items()
         )
         raise click.ClickException(
             f"Conflicting migrations detected; multiple leaf nodes in the "
-            f"migration graph: ({name_str}).\nTo fix them run "
-            f"'python manage.py makemigrations --merge'"
+            f"migration graph: ({name_str})."
         )
 
-    # Handle merge if requested
-    if merge and conflicts:
-        return handle_merge(loader, conflicts)
-
     # Set up questioner
     if interactive:
         questioner = InteractiveMigrationQuestioner(
@@ -402,11 +325,6 @@ def makemigrations(
 @click.option(
     "--fake", is_flag=True, help="Mark migrations as run without actually running them."
 )
-@click.option(
-    "--fake-initial",
-    is_flag=True,
-    help="Detect if tables already exist and fake-apply initial migrations if so. Make sure that the current database schema matches your initial migration before using this flag. Plain will only check for an existing table name.",
-)
 @click.option(
     "--plan",
     is_flag=True,
@@ -430,6 +348,13 @@ def makemigrations(
     is_flag=True,
     help="Delete nonexistent migrations from the plainmigrations table.",
 )
+@click.option(
+    "--no-input",
+    "--noinput",
+    "no_input",
+    is_flag=True,
+    help="Tells Plain to NOT prompt the user for input of any kind.",
+)
 @click.option(
     "-v",
     "--verbosity",
@@ -441,11 +366,11 @@ def migrate(
     package_label,
     migration_name,
     fake,
-    fake_initial,
     plan,
     check_unapplied,
     backup,
     prune,
+    no_input,
     verbosity,
 ):
     """Updates database schema. Manages both packages with migrations and those without."""
@@ -502,8 +427,7 @@ def migrate(
         )
         raise click.ClickException(
             "Conflicting migrations detected; multiple leaf nodes in the "
-            f"migration graph: ({name_str}).\nTo fix them run "
-            "'python manage.py makemigrations --merge'"
+            f"migration graph: ({name_str})."
         )
 
     # If they supplied command line arguments, work out what they mean.
@@ -578,7 +502,7 @@ def migrate(
                 click.echo(f"    {package}.{name}")
             click.echo(
                 click.style(
-                    "  Re-run 'manage.py migrate' if they are not marked as "
+                    "  Re-run `plain migrate` if they are not marked as "
                     "applied, and remove 'replaces' attributes in their "
                     "Migration classes.",
                     fg="yellow",
@@ -654,9 +578,12 @@ def migrate(
         if backup or (
             backup is None
             and settings.DEBUG
-            and click.confirm(
-                "\nYou are in DEBUG mode. Would you like to make a database backup before running migrations?",
-                default=True,
+            and (
+                no_input
+                or click.confirm(
+                    "\nYou are in DEBUG mode. Would you like to make a database backup before running migrations?",
+                    default=True,
+                )
             )
         ):
             backup_name = f"migrate_{time.strftime('%Y%m%d_%H%M%S')}"
@@ -678,7 +605,6 @@ def migrate(
             plan=migration_plan,
             state=pre_migrate_state.clone(),
             fake=fake,
-            fake_initial=fake_initial,
         )
         # post_migrate signals have access to all models. Ensure that all models
         # are reloaded in case any are delayed.
@@ -720,117 +646,14 @@ def migrate(
             )
             click.echo(
                 click.style(
-                    "  Run 'manage.py makemigrations' to make new "
-                    "migrations, and then re-run 'manage.py migrate' to "
+                    "  Run `plain makemigrations` to make new "
+                    "migrations, and then re-run `plain migrate` to "
                     "apply them.",
                     fg="yellow",
                 )
             )
 
 
-@cli.command()
-@click.argument("package_label")
-@click.argument("migration_name")
-@click.option(
-    "--check",
-    is_flag=True,
-    help="Exit with a non-zero status if the migration can be optimized.",
-)
-@click.option(
-    "-v",
-    "--verbosity",
-    type=int,
-    default=1,
-    help="Verbosity level; 0=minimal output, 1=normal output, 2=verbose output, 3=very verbose output",
-)
-def optimize_migration(package_label, migration_name, check, verbosity):
-    """Optimizes the operations for the named migration."""
-    try:
-        packages_registry.get_package_config(package_label)
-    except LookupError as err:
-        raise click.ClickException(str(err))
-
-    # Load the current graph state.
-    loader = MigrationLoader(None)
-    if package_label not in loader.migrated_packages:
-        raise click.ClickException(
-            f"Package '{package_label}' does not have migrations."
-        )
-
-    # Find a migration.
-    try:
-        migration = loader.get_migration_by_prefix(package_label, migration_name)
-    except AmbiguityError:
-        raise click.ClickException(
-            f"More than one migration matches '{migration_name}' in package "
-            f"'{package_label}'. Please be more specific."
-        )
-    except KeyError:
-        raise click.ClickException(
-            f"Cannot find a migration matching '{migration_name}' from package "
-            f"'{package_label}'."
-        )
-
-    # Optimize the migration.
-    optimizer = MigrationOptimizer()
-    new_operations = optimizer.optimize(migration.operations, migration.package_label)
-    if len(migration.operations) == len(new_operations):
-        if verbosity > 0:
-            click.echo("No optimizations possible.")
-        return
-    else:
-        if verbosity > 0:
-            click.echo(
-                f"Optimizing from {len(migration.operations)} operations to {len(new_operations)} operations."
-            )
-        if check:
-            sys.exit(1)
-
-    # Set the new migration optimizations.
-    migration.operations = new_operations
-
-    # Write out the optimized migration file.
-    writer = MigrationWriter(migration)
-    migration_file_string = writer.as_string()
-    if writer.needs_manual_porting:
-        if migration.replaces:
-            raise click.ClickException(
-                "Migration will require manual porting but is already a squashed "
-                "migration.\nTransition to a normal migration first."
-            )
-        # Make a new migration with those operations.
-        subclass = type(
-            "Migration",
-            (migrations.Migration,),
-            {
-                "dependencies": migration.dependencies,
-                "operations": new_operations,
-                "replaces": [(migration.package_label, migration.name)],
-            },
-        )
-        optimized_migration_name = f"{migration.name}_optimized"
-        optimized_migration = subclass(optimized_migration_name, package_label)
-        writer = MigrationWriter(optimized_migration)
-        migration_file_string = writer.as_string()
-        if verbosity > 0:
-            click.echo(click.style("Manual porting required", fg="yellow", bold=True))
-            click.echo(
-                "  Your migrations contained functions that must be manually "
-                "copied over,\n"
-                "  as we could not safely copy their implementation.\n"
-                "  See the comment at the top of the optimized migration for "
-                "details."
-            )
-
-    with open(writer.path, "w", encoding="utf-8") as fh:
-        fh.write(migration_file_string)
-
-    if verbosity > 0:
-        click.echo(
-            click.style(f"Optimized migration {writer.path}", fg="green", bold=True)
-        )
-
-
 @cli.command()
 @click.argument("package_labels", nargs=-1)
 @click.option(
@@ -895,7 +718,7 @@ def show_migrations(package_labels, format, verbosity):
                             if plan_node in recorded_migrations:
                                 output = f" [X] {title}"
                             else:
-                                title += " Run 'manage.py migrate' to finish recording."
+                                title += " Run `plain migrate` to finish recording."
                                 output = f" [-] {title}"
                             if verbosity >= 2 and hasattr(applied_migration, "applied"):
                                 output += f" (applied at {applied_migration.applied.strftime('%Y-%m-%d %H:%M:%S')})"
@@ -1075,7 +898,7 @@ def squash_migrations(
                 f"The migration '{start_migration}' cannot be found. Maybe it comes after "
                 f"the migration '{migration}'?\n"
                 f"Have a look at:\n"
-                f"  python manage.py showmigrations {package_label}\n"
+                f"  plain models show-migrations {package_label}\n"
                 f"to debug this issue."
             )
 
