@@ -37,7 +37,7 @@ def construct_instance(form, instance, fields=None):
     cleaned_data = form.cleaned_data
     file_field_list = []
     for f in opts.fields:
-        if isinstance(f, models.AutoField) or f.name not in cleaned_data:
+        if isinstance(f, models.PrimaryKeyField) or f.name not in cleaned_data:
             continue
         if fields is not None and f.name not in fields:
             continue
@@ -318,17 +318,6 @@ class BaseModelForm(BaseForm):
 
         exclude = self._get_validation_exclusions()
 
-        # Foreign Keys being used to represent inline relationships
-        # are excluded from basic field value validation. This is for two
-        # reasons: firstly, the value may not be supplied (#12507; the
-        # case of providing new values to the admin); secondly the
-        # object being referred to may not yet fully exist (#12749).
-        # However, these fields *must* be included in uniqueness checks,
-        # so this can't be part of _get_validation_exclusions().
-        for name, field in self.fields.items():
-            if isinstance(field, InlineForeignKeyField):
-                exclude.add(name)
-
         try:
             self.instance = construct_instance(self, self.instance, opts.fields)
         except ValidationError as e:
@@ -401,49 +390,6 @@ class ModelForm(BaseModelForm, metaclass=ModelFormMetaclass):
 # Fields #####################################################################
 
 
-class InlineForeignKeyField(Field):
-    """
-    A basic integer field that deals with validating the given value to a
-    given parent instance in an inline.
-    """
-
-    default_error_messages = {
-        "invalid_choice": "The inline value did not match the parent instance.",
-    }
-
-    def __init__(self, parent_instance, *args, pk_field=False, to_field=None, **kwargs):
-        self.parent_instance = parent_instance
-        self.pk_field = pk_field
-        self.to_field = to_field
-        if self.parent_instance is not None:
-            if self.to_field:
-                kwargs["initial"] = getattr(self.parent_instance, self.to_field)
-            else:
-                kwargs["initial"] = self.parent_instance.pk
-        kwargs["required"] = False
-        super().__init__(*args, **kwargs)
-
-    def clean(self, value):
-        if value in self.empty_values:
-            if self.pk_field:
-                return None
-            # if there is no value act as we did before.
-            return self.parent_instance
-        # ensure the we compare the values as equal types.
-        if self.to_field:
-            orig = getattr(self.parent_instance, self.to_field)
-        else:
-            orig = self.parent_instance.pk
-        if str(value) != str(orig):
-            raise ValidationError(
-                self.error_messages["invalid_choice"], code="invalid_choice"
-            )
-        return self.parent_instance
-
-    def has_changed(self, initial, data):
-        return False
-
-
 class ModelChoiceIteratorValue:
     def __init__(self, value, instance):
         self.value = value
@@ -509,7 +455,6 @@ class ModelChoiceField(ChoiceField):
         empty_label="---------",
         required=True,
         initial=None,
-        to_field_name=None,
         **kwargs,
     ):
         # Call Field instead of ChoiceField __init__() because we don't need
@@ -525,7 +470,6 @@ class ModelChoiceField(ChoiceField):
         else:
             self.empty_label = empty_label
         self.queryset = queryset
-        self.to_field_name = to_field_name
 
     def __deepcopy__(self, memo):
         result = super(ChoiceField, self).__deepcopy__(memo)
@@ -561,17 +505,14 @@ class ModelChoiceField(ChoiceField):
 
     def prepare_value(self, value):
         if hasattr(value, "_meta"):
-            if self.to_field_name:
-                return value.serializable_value(self.to_field_name)
-            else:
-                return value.pk
+            return value.id
         return super().prepare_value(value)
 
     def to_python(self, value):
         if value in self.empty_values:
             return None
         try:
-            key = self.to_field_name or "pk"
+            key = "id"
             if isinstance(value, self.queryset.model):
                 value = getattr(value, key)
             value = self.queryset.get(**{key: value})
@@ -598,7 +539,7 @@ class ModelMultipleChoiceField(ModelChoiceField):
     default_error_messages = {
         "invalid_list": "Enter a list of values.",
         "invalid_choice": "Select a valid choice. %(value)s is not one of the available choices.",
-        "invalid_pk_value": "“%(pk)s” is not a valid value.",
+        "invalid_id_value": "'%(id)s' is not a valid value.",
     }
 
     def __init__(self, queryset, **kwargs):
@@ -632,7 +573,6 @@ class ModelMultipleChoiceField(ModelChoiceField):
         corresponding objects. Raise a ValidationError if a given value is
         invalid (not a valid PK, not in the queryset, etc.)
         """
-        key = self.to_field_name or "pk"
         # deduplicate given values to avoid creating many querysets or
         # requiring the database backend deduplicate efficiently.
         try:
@@ -643,19 +583,19 @@ class ModelMultipleChoiceField(ModelChoiceField):
                 self.error_messages["invalid_list"],
                 code="invalid_list",
             )
-        for pk in value:
+        for id_val in value:
             try:
-                self.queryset.filter(**{key: pk})
+                self.queryset.filter(id=id_val)
             except (ValueError, TypeError):
                 raise ValidationError(
-                    self.error_messages["invalid_pk_value"],
-                    code="invalid_pk_value",
-                    params={"pk": pk},
+                    self.error_messages["invalid_id_value"],
+                    code="invalid_id_value",
+                    params={"id": id_val},
                 )
-        qs = self.queryset.filter(**{f"{key}__in": value})
-        pks = {str(getattr(o, key)) for o in qs}
+        qs = self.queryset.filter(id__in=value)
+        ids = {str(o.id) for o in qs}
         for val in value:
-            if str(val) not in pks:
+            if str(val) not in ids:
                 raise ValidationError(
                     self.error_messages["invalid_choice"],
                     code="invalid_choice",
@@ -733,10 +673,8 @@ def modelfield_to_formfield(
     # Avoid a circular import
     from plain import models
 
-    # Auto fields aren't rendered by default
-    if isinstance(modelfield, models.AutoField) or issubclass(
-        modelfield.__class__, models.AutoField
-    ):
+    # Primary key fields aren't rendered by default
+    if isinstance(modelfield, models.PrimaryKeyField):
         return None
 
     if isinstance(modelfield, models.BooleanField):
@@ -784,7 +722,6 @@ def modelfield_to_formfield(
     if isinstance(modelfield, models.ForeignKey):
         return ModelChoiceField(
             queryset=modelfield.remote_field.model._default_manager,
-            to_field_name=modelfield.remote_field.field_name,
             **defaults,
         )
 
