@@ -536,7 +536,7 @@ class MigrationAutodetector:
                     if field.remote_field.model:
                         if field.primary_key:
                             primary_key_rel = field.remote_field.model
-                        elif not field.remote_field.parent_link:
+                        else:
                             related_fields[field_name] = field
                     if getattr(field.remote_field, "through", None):
                         related_fields[field_name] = field
@@ -938,31 +938,8 @@ class MigrationAutodetector:
                 if remote_field_name:
                     to_field_rename_key = rename_key + (remote_field_name,)
                     if to_field_rename_key in self.renamed_fields:
-                        # Repoint both model and field name because to_field
-                        # inclusion in ForeignKey.deconstruct() is based on
-                        # both.
+                        # Repoint model name only
                         new_field.remote_field.model = old_field.remote_field.model
-                        new_field.remote_field.field_name = (
-                            old_field.remote_field.field_name
-                        )
-                # Handle ForeignObjects which can have multiple from_fields/to_fields.
-                from_fields = getattr(new_field, "from_fields", None)
-                if from_fields:
-                    from_rename_key = (package_label, model_name)
-                    new_field.from_fields = tuple(
-                        [
-                            self.renamed_fields.get(
-                                from_rename_key + (from_field,), from_field
-                            )
-                            for from_field in from_fields
-                        ]
-                    )
-                    new_field.to_fields = tuple(
-                        [
-                            self.renamed_fields.get(rename_key + (to_field,), to_field)
-                            for to_field in new_field.to_fields
-                        ]
-                    )
                 dependencies.extend(
                     self._get_dependencies_for_foreign_key(
                         package_label,
