@@ -313,8 +313,6 @@ def select_related_descend(field, restricted, requested, select_mask, reverse=Fa
     """
     if not field.remote_field:
         return False
-    if field.remote_field.parent_link and not reverse:
-        return False
     if restricted:
         if reverse and field.related_query_name() not in requested:
             return False
@@ -363,11 +361,11 @@ def check_rel_lookup_compatibility(model, target_opts, field):
     # model is ok, too. Consider the case:
     # class Restaurant(models.Model):
     #     place = OneToOneField(Place, primary_key=True):
-    # Restaurant.objects.filter(pk__in=Restaurant.objects.all()).
-    # If we didn't have the primary key check, then pk__in (== place__in) would
+    # Restaurant.objects.filter(id__in=Restaurant.objects.all()).
+    # If we didn't have the primary key check, then id__in (== place__in) would
     # give Place's opts as the target opts, but Restaurant isn't compatible
     # with that. This logic applies only to primary keys, as when doing __in=qs,
-    # we are going to turn this into __in=qs.values('pk') later on.
+    # we are going to turn this into __in=qs.values('id') later on.
     return check(target_opts) or (
         getattr(field, "primary_key", False) and check(field.model._meta)
     )
