@@ -47,10 +47,13 @@ class ChildSetNull(models.Model):
 
 @models.register_model
 class ChildSetDefault(models.Model):
+    def default_parent_id():
+        return DeleteParent.objects.get(name="default").id
+
     parent = models.ForeignKey(
         DeleteParent,
         on_delete=models.SET_DEFAULT,
-        default=1,
+        default=default_parent_id,
     )
 
 
